@@ -4,6 +4,7 @@ $POWERLINE_COMMAND = "oh-my-posh"
 $POSH_THEME = r"::CONFIG::"
 $POSH_PID = uuid.uuid4().hex
 $POSH_SHELL_VERSION = $XONSH_VERSION
+$POSH_EXECUTABLE = r"::OMP::"
 
 def get_command_context():
     last_cmd = __xonsh__.history[-1] if __xonsh__.history else None
@@ -13,17 +14,12 @@ def get_command_context():
 
 def posh_primary():
     status, duration = get_command_context()
-    return $(::OMP:: print primary --config=@($POSH_THEME) --shell=xonsh --status=@(status) --execution-time=@(duration) --shell-version=@($POSH_SHELL_VERSION))
+    return $(@($POSH_EXECUTABLE) print primary --shell=xonsh --status=@(status) --execution-time=@(duration) --shell-version=@($POSH_SHELL_VERSION))
 
 def posh_right():
     status, duration = get_command_context()
-    return $(::OMP:: print right --config=@($POSH_THEME) --shell=xonsh --status=@(status) --execution-time=@(duration) --shell-version=@($POSH_SHELL_VERSION))
+    return $(@($POSH_EXECUTABLE) print right --shell=xonsh --status=@(status) --execution-time=@(duration) --shell-version=@($POSH_SHELL_VERSION))
 
 
 $PROMPT = posh_primary
 $RIGHT_PROMPT = posh_right
-
-notice = """::UPGRADENOTICE::"""
-
-if "::UPGRADE::" == "true":
-  print(notice)
